__version__ = "0.5.2"

"""
Version: 0.5.2: Add canvas init from image and setters from scalars
Version: 0.5.1: Add canvas.rgb getter/setter to quickly get non-alpha img
Version: 0.5.0: Resize function in canvas.resize (removed transform.scale)
Version: 0.4.9: Loading from file now respects an alpha channel
Version: 0.4.8: Fix load from file to have correct pixels_per_unit
Version: 0.4.7: Fix copy/blank error
Version: 0.4.6: polyLines can now be filled
Version: 0.4.5: Added glow filter, slow but pretty
Version: 0.4.4: Colors now take hex code. Fix numpy error w/new version.
Version: 0.4.3: canvas.show() now returns the keycode.
Version: 0.4.2: Add helper load function directly from pixelhouse.
Version: 0.4.1: Add helper functions to see all the color palettes.
Version: 0.4.0: transform_length was off by a factor of two. Ouch. Fixed all the examples and code (mostly circle radii). This may break older code.
Version: 0.3.3: 100% Coverage. Fixed tiny bugs while building unit tests
Version: 0.3.2: Removed unnecessary debug statement and added animated pixelhouse logo example.
Version: 0.3.1: Fixed the manifest so the font files load.
Version: 0.3.0: Cleaned up easing API, now much cleaner and _easier_ to use. Ha.
Version: 0.2.2: Canvas now operates as an array (you can index and change the values as a numpy array). canvas._img is now simply canvas.img
Version: 0.2.1: Add three new functions, hstack, vstack, and grid stack
Version: 0.2.0: Improved gradients (multi colors, discrete, and transparency). Changed gradient API. Fixed a few canvas bugs. Added canvas properties like C.xmax.
Version: 0.1.5: Escape animations with any key
Version: 0.1.4: Added a wave effect transform
Version: 0.1.3: Moved ColorLoversPalette to just palette
Version: 0.1.2: Fixed MANIFEST! Missing assets
Version: 0.1.1: Refactored .filter to .filters to prevent namespace collision
Version: 0.1.0: First release! Added subpixel resolution to prior work.
"""
